Animanager
==========

Animanager_ is a command line program for advanced anime watching management.

.. _Animanager: https://darkfeline.github.io/animanager/

Documentation can be found online at `Read the Docs`_ or in the included ``doc``
directory.

.. _Read the Docs: http://animanager.readthedocs.org/
